@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,24 +13,30 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.cloud.workflows.executions_v1beta import gapic_version as package_version
 
-from .services.executions import ExecutionsClient
-from .types.executions import CancelExecutionRequest
-from .types.executions import CreateExecutionRequest
-from .types.executions import Execution
-from .types.executions import ExecutionView
-from .types.executions import GetExecutionRequest
-from .types.executions import ListExecutionsRequest
-from .types.executions import ListExecutionsResponse
+__version__ = package_version.__version__
 
 
+from .services.executions import ExecutionsAsyncClient, ExecutionsClient
+from .types.executions import (
+    CancelExecutionRequest,
+    CreateExecutionRequest,
+    Execution,
+    ExecutionView,
+    GetExecutionRequest,
+    ListExecutionsRequest,
+    ListExecutionsResponse,
+)
+
 __all__ = (
+    "ExecutionsAsyncClient",
     "CancelExecutionRequest",
     "CreateExecutionRequest",
     "Execution",
     "ExecutionView",
+    "ExecutionsClient",
     "GetExecutionRequest",
     "ListExecutionsRequest",
     "ListExecutionsResponse",
-    "ExecutionsClient",
 )
