@@ -58,6 +58,7 @@ from google.cloud.workflows_v1.types import workflows
 from .transports.base import DEFAULT_CLIENT_INFO, WorkflowsTransport
 from .transports.grpc import WorkflowsGrpcTransport
 from .transports.grpc_asyncio import WorkflowsGrpcAsyncIOTransport
+from .transports.rest import WorkflowsRestTransport
 
 
 class WorkflowsClientMeta(type):
@@ -71,6 +72,7 @@ class WorkflowsClientMeta(type):
     _transport_registry = OrderedDict()  # type: Dict[str, Type[WorkflowsTransport]]
     _transport_registry["grpc"] = WorkflowsGrpcTransport
     _transport_registry["grpc_asyncio"] = WorkflowsGrpcAsyncIOTransport
+    _transport_registry["rest"] = WorkflowsRestTransport
 
     def get_transport_class(
         cls,
@@ -297,7 +299,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -1091,7 +1093,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "WorkflowsClient":
         return self
 
     def __exit__(self, type, value, traceback):
